@@ -1,12 +1,12 @@
 package IO::Stream;
-
+use 5.010001;
 use warnings;
 use strict;
+use utf8;
 use Carp;
 
-use version; our $VERSION = qv('1.0.10');    # update POD & Changes & README
+our $VERSION = 'v2.0.0';
 
-# update DEPENDENCIES in POD & Makefile.PL & README
 use Scalar::Util qw( weaken );
 
 
@@ -193,6 +193,8 @@ sub EVENT {
 1; # Magic true value required at end of module
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 IO::Stream - ease non-blocking I/O streams based on EV
@@ -200,7 +202,7 @@ IO::Stream - ease non-blocking I/O streams based on EV
 
 =head1 VERSION
 
-This document describes IO::Stream version 1.0.10
+This document describes IO::Stream version v2.0.0
 
 
 =head1 SYNOPSIS
@@ -285,6 +287,10 @@ Errors:
 Errors are similar to $! - they're dualvars, having both textual and numeric
 values.
 
+B<NOTE:> Since v2.0.0 C<ETORESOLVE>, C<EDNSNXDOMAIN> and C<EDNSNODATA> are
+not used anymore (C<EDNS> is used instead), but they're still exported for
+compatibility.
+
 
 =head1 OVERVIEW
 
@@ -365,7 +371,7 @@ call $stream->close() on SENT event.
 =head2 TIMEOUTS
 
 IO::Stream has 30-second timeouts for connect and write,
-to timeout DNS resolve it use default EV::ADNS timeout.
+to timeout DNS resolve it use default AnyEvent::DNS timeout.
 If you need to timeout other operations, you have to create own timers
 using EV::timer().
 
@@ -671,67 +677,68 @@ number, and you've tried to create IO::Stream object using new fh.
 =back
 
 
-=head1 CONFIGURATION AND ENVIRONMENT
-
-IO::Stream requires no configuration files or environment variables.
-
-
-=head1 DEPENDENCIES
-
-L<EV>, L<EV::ADNS>
-
-
-=head1 INCOMPATIBILITIES
-
-None reported.
-
-
-=head1 BUGS AND LIMITATIONS
-
-No bugs have been reported.
-
-Please report any bugs or feature requests to author, or
-C<bug-ev-stream@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
-
-
 =head1 SEE ALSO
 
 L<AnyEvent::Handle>
 
 
+=head1 SUPPORT
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/powerman/perl-IO-Stream/issues>.
+You will be notified automatically of any progress on your issue.
+
+=head2 Source Code
+
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
+Feel free to fork the repository and submit pull requests.
+
+L<https://github.com/powerman/perl-IO-Stream>
+
+    git clone https://github.com/powerman/perl-IO-Stream.git
+
+=head2 Resources
+
+=over
+
+=item * MetaCPAN Search
+
+L<https://metacpan.org/search?q=IO-Stream>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/dist/IO-Stream>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/IO-Stream>
+
+=item * CPAN Testers Matrix
+
+L<http://matrix.cpantesters.org/?dist=IO-Stream>
+
+=item * CPANTS: A CPAN Testing Service (Kwalitee)
+
+L<http://cpants.cpanauthors.org/dist/IO-Stream>
+
+=back
+
+
 =head1 AUTHOR
 
-Alex Efros  C<< <powerman-asdf@ya.ru> >>
+Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2008,2014,2016, Alex Efros C<< <powerman-asdf@ya.ru> >>. All rights reserved.
+This software is Copyright (c) 2008-2016 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+=cut
