@@ -1,19 +1,18 @@
 package IO::Stream::EV;
-
+use 5.010001;
 use warnings;
 use strict;
+use utf8;
+use Carp;
 
-use version; our $VERSION = qv('1.0.10');
+our $VERSION = 'v2.0.0';
 
 use IO::Stream::const;
 
-# update DEPENDENCIES in POD & Makefile.PL & README
 use Scalar::Util qw( weaken );
 use Socket qw( inet_aton sockaddr_in );
 use EV;
-BEGIN { if (!WIN32) { eval 'use EV::ADNS; 1' or die $@ }} ## no critic (ProhibitStringyEval RequireCarping)
-
-
+use AnyEvent::DNS;
 
 # States:
 use constant RESOLVING      => 1;
@@ -51,7 +50,7 @@ sub PREPARE {
     }
     else {
         $self->{_state} = RESOLVING;
-        resolve($host, $self, sub {
+        _resolve($host, $self, sub {
             my ($self, $ip) = @_;
             $self->{_state} = CONNECTING;
             # TODO try other ip on failed connect?
@@ -74,31 +73,22 @@ sub WRITE {
     return;
 }
 
-sub resolve {
+sub _resolve {
     my ($host, $plugin, $cb) = @_;
     if ($host =~ /\A\d{1,3}[.]\d{1,3}[.]\d{1,3}[.]\d{1,3}\z/xms) {
         $cb->($plugin, $host);
     }
-    elsif (WIN32) {
-        my $iaddr = inet_aton($host);
-        if ($iaddr) {
-            $cb->($plugin, join q{.}, unpack 'C4', $iaddr);
-        }
-        else {
-            $plugin->{_master}->EVENT(0, EDNSNXDOMAIN);
-        }
-    }
     else {
         weaken($plugin);
-        # WARNING   ADNS has own timeouts, so we don't setup own here.
-        EV::ADNS::submit $host, EV::ADNS::r_a(), 0, sub {
-            my ($status, undef, @a) = @_;
+        # AnyEvent::DNS has own timeouts, so we don't setup own here.
+        AnyEvent::DNS::a $host, sub {
+            my (@a) = @_;
             return if !$plugin;
-            if ($status == EV::ADNS::s_ok()) {
+            if (@a) {
                 $cb->($plugin, @a);
             }
             else {
-                $plugin->{_master}->EVENT(0, adns2err($status));
+                $plugin->{_master}->EVENT(0, EDNS);
             }
             return;
         };
@@ -106,15 +96,6 @@ sub resolve {
     return;
 }
 
-sub adns2err {
-    my ($status) = @_;
-    return
-        $status == EV::ADNS::s_timeout()  ? ETORESOLVE
-      : $status == EV::ADNS::s_nxdomain() ? EDNSNXDOMAIN
-      : $status == EV::ADNS::s_nodata()   ? EDNSNODATA
-      :                                     EDNS
-}
-
 sub T {
     my ($self) = @_;
     my $m = $self->{_master};
