@@ -1,9 +1,12 @@
 # No-op plugin example.
 package IO::Stream::Noop;
+use 5.010001;
 use warnings;
 use strict;
+use utf8;
+use Carp;
 
-use version; our $VERSION = qv('1.0.10');
+our $VERSION = 'v2.0.0';
 
 use IO::Stream::const;
 
